@@ -1,3 +1,4 @@
+import json
 import sys
 import time
 from manafa.services.batteryStatsService import BatteryStatsService
@@ -352,3 +353,23 @@ class EManafa(Service):
         """plugs back the device"""
         res, o, e = execute_shell_command("adb shell dumpsys battery reset")
         self.unplugged = False
+
+    def gen_final_report(self, start_time=None, end_time=None):
+        begin = self.perf_events.events[0].time if start_time is None else start_time
+        end = self.perf_events.events[-1].time if end_time is None else end_time
+        total, per_c, timeline = self.get_consumption_in_between(begin, end)
+        res = {
+            'total_energy:': total,
+            'elapsed_time': end-begin,
+            'per_component_consumption': per_c,
+            'stats': timeline,
+            'method_invocations': 0,
+            'diff_methods': 0
+        }
+        return {'global': res}
+
+    def save_final_report(self, run_id=None, output_filepath=None):
+        if output_filepath is None:
+            output_filepath = "manafa_resume_%s.json" % (run_id if run_id is not None else 0)
+        with open(output_filepath, 'w') as j:
+            json.dump(self.gen_final_report(), j)
